<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>LXQt滑鼠游標主題設定</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>選擇你想使用的游標主題 (來回移動來測試游標). &lt;b&gt;改變後需重新啟動LXQt會話&lt;/b&gt;：</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>安裝新主題 (&amp;I)...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>移除主題(&amp;R)</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="212"/>
        <source>XCurTheme error</source>
        <translation>XCurTheme錯誤</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="213"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>您無法移除正在套用的主題!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>表單</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt找不到任何游標主題，將改為使用X11預設的游標主題，LXQt在下列目錄中尋找：</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>顯示...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
</context>
</TS>
